@@ -41,13 +41,15 @@ class ImsClient(AbstractClient):
         - 支持用户自定义选择图片风险库，打击自定义识别类型的违规图片（目前仅支持黑名单配置）；
         - 支持在审核图片内容时同时关联账号或设备信息，可识别违规风险账号或设备。
         ### 接口调用说明：
-        - 图片文件大小支持：**文件<100M**
+        - 图片文件大小限制：**Base64编码内容应小于10MB**；**图片资源应小于100MB**
         - 图片尺寸支持：**长和宽 需>50分辨率且<40000分辨率，并且图片长宽比<90:1；**
         - 图片文件分辨率支持：建议**分辨率大于256x256**，否则可能会影响识别效果；
         - 图片文件支持格式：PNG、JPG、JPEG、BMP、GIF、WEBP格式；
         - 图片文件链接支持的传输协议：HTTP、HTTPS；
         - 若传入图片文件的访问链接，则需要注意**图片下载时间限制为3秒**，为保障被检测图片的稳定性和可靠性，建议您使用腾讯云COS存储或者CDN缓存等；
         - 默认接口请求频率限制：**20次/秒**，超过此调用频率则会报错。
+        - ### 接口回调格式：
+        - 图片异步检测接口回调格式同[图片同步检测接口输出参数](https://cloud.tencent.com/document/product/1125/53273#3.-.E8.BE.93.E5.87.BA.E5.8F.82.E6.95.B0)
 
         :param request: Request instance for CreateImageModerationAsyncTask.
         :type request: :class:`tencentcloud.ims.v20201229.models.CreateImageModerationAsyncTaskRequest`
@@ -85,7 +87,7 @@ class ImsClient(AbstractClient):
         - 支持在审核图片内容时同时关联账号或设备信息，可识别违规风险账号或设备。
 
         ### 接口调用说明：
-        - 图片文件大小支持：**文件 < 30M**
+        - 图片文件大小限制：**Base64编码内容应小于10MB**；**URL资源应小于30MB**
         - 图片默认尺寸支持：**长和宽 需>50分辨率且<10000分辨率，并且图片长宽比<90:1；**
         - 图片文件分辨率支持：建议**分辨率大于256x256**，否则可能会影响识别效果；
         - 图片文件支持格式：PNG、JPG、JPEG、BMP、GIF、WEBP格式；
