@@ -77,6 +77,9 @@ FAILEDOPERATION_EMAILALREADYUSED = 'FailedOperation.EmailAlreadyUsed'
 # 邮箱绑定已经失效。
 FAILEDOPERATION_EMAILBINDRECORDINVALID = 'FailedOperation.EmailBindRecordInvalid'
 
+# 存在不在组织内的共享成员。
+FAILEDOPERATION_EXISTSHAREMEMBERNOTINORGANIZATION = 'FailedOperation.ExistShareMemberNotInOrganization'
+
 # 查询实名信息出错。
 FAILEDOPERATION_GETAUTHINFO = 'FailedOperation.GetAuthInfo'
 
@@ -206,6 +209,9 @@ FAILEDOPERATION_RESOURCEOVERLIMIT = 'FailedOperation.ResourceOverLimit'
 # 共享地域不存在。
 FAILEDOPERATION_SHAREAREANOTEXIST = 'FailedOperation.ShareAreaNotExist'
 
+# 共享成员不存在。
+FAILEDOPERATION_SHAREMEMBERNOTEXIST = 'FailedOperation.ShareMemberNotExist'
+
 # 成员正在使用共享资源。
 FAILEDOPERATION_SHARERESOURCEMEMBERINUSE = 'FailedOperation.ShareResourceMemberInUse'
 
@@ -416,6 +422,9 @@ RESOURCENOTFOUND_APPLYNOTEXIST = 'ResourceNotFound.ApplyNotExist'
 # 成员权限变更记录不存在。
 RESOURCENOTFOUND_CHANGEPERMISSIONNOTEXIST = 'ResourceNotFound.ChangePermissionNotExist'
 
+# 有效策略不存在。
+RESOURCENOTFOUND_EFFECTIVEPOLICYNOTFOUND = 'ResourceNotFound.EffectivePolicyNotFound'
+
 # 邮箱绑定记录不存在。
 RESOURCENOTFOUND_EMAILBINDRECORDNOTEXIST = 'ResourceNotFound.EmailBindRecordNotExist'
 
@@ -574,3 +583,6 @@ UNSUPPORTEDOPERATION_PAYEREXISTACCOUNTLEVELDISCOUNTINHERIT = 'UnsupportedOperati
 
 # 存在二级经销商子客，不支持代付费。
 UNSUPPORTEDOPERATION_SECONDARYDISTRIBUTORSUBCLIENTEXISTED = 'UnsupportedOperation.SecondaryDistributorSubClientExisted'
+
+# 不支持共享给其他组织成员。
+UNSUPPORTEDOPERATION_SHARINGTOOTHERORGANIZATIONMEMBER = 'UnsupportedOperation.SharingToOtherOrganizationMember'
